#
# spec file for package ocaml-dune
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define build_flavor %nil
%if "%build_flavor" == ""
%define nsuffix %nil
%else
%define nsuffix -%build_flavor
%endif

%define     pkg ocaml-dune
%global  _buildshell /bin/bash
Name:           %pkg%nsuffix
Version:        3.15.0
Release:        1.1
%{?ocaml_preserve_bytecode}
License:        MIT
Group:          Development/Languages/OCaml
BuildRoot:      %_tmppath/%name-%version-build
URL:            https://opam.ocaml.org/packages/dune
Source0:        %pkg-%version.tar.xz
Requires:       ocamlfind(compiler-libs)
BuildRequires:  ocaml-rpm-macros >= 20231101
BuildRequires:  ocaml(ocaml_base_version) >= 4.08
%if "%build_flavor" == ""
Provides:       %name-bootstrap = %version-%release
Provides:       %name-bootstrap-devel = %version-%release
Obsoletes:      %name-bootstrap < %version-%release
Obsoletes:      %name-bootstrap-devel < %version-%release
Summary:        A composable build system for OCaml
%description
This package provides the dune binary and the documentation.
%endif
%if "%build_flavor" == "devel"
Summary:        Various libraries
Group:          Development/Languages/OCaml
BuildRequires:  ocaml-dune = %version
BuildRequires:  ocamlfind(csexp)
BuildRequires:  ocamlfind(pp)
Provides:       ocaml-dune-configurator == %version-%release
Obsoletes:      ocaml-dune-configurator <  %version-%release
Provides:       ocaml-dune-configurator-devel == %version-%release
Obsoletes:      ocaml-dune-configurator-devel <  %version-%release

%description
This package provides various libraries:
chrome-trace
dune-action-plugin
dune-build-info
dune-configurator
dune-glob
dune-private-libs
dune-rpc
dune-site
dyn
ocamlc-loc
ordering
stdune
xdg
%endif

%prep
%setup -q -n %pkg-%version

%build
mv -vb src/dune_rules/setup.defaults.ml src/dune_rules/setup.ml
bash configure \
	'--bindir=%_bindir' \
	'--datadir=%_datadir' \
	'--etcdir=%_sysconfdir' \
	'--libdir=%ocaml_standard_library' \
	'--libexecdir=%_libexecdir' \
	'--mandir=%_mandir' \
	'--sbindir=%_sbindir' \
	%nil
#
%if "%build_flavor" == ""
dune_release_pkgs='dune'
%ocaml_dune_setup
jobs="-j `/usr/bin/getconf _NPROCESSORS_ONLN`"
ocaml boot/bootstrap.ml --verbose ${jobs}
./_boot/dune.exe build \
	dune.install \
	--release \
	--profile dune-bootstrap \
	--verbose \
	${jobs} \
	%nil
mkdir .bin
ln -sv ../_boot/dune.exe .bin/dune
%endif
#
%if "%build_flavor" == "devel"
pkgs=(
chrome-trace
dune-action-plugin
dune-build-info
dune-configurator
dune-glob
dune-private-libs
dune-rpc
dune-site
dyn
ocamlc-loc
ordering
stdune
xdg
)
dune_release_pkgs="${pkgs[*]}"
dune_release_pkgs="${dune_release_pkgs// /,}"
#
%ocaml_dune_setup
%ocaml_dune_build
%endif

%install
# use the just built dune
PATH="$PWD/.bin:$PATH"
%ocaml_dune_install
%if "%build_flavor" == ""
# the installed META file provides and requires 'dune-configurator'
rm -rfv %buildroot%ocaml_standard_library
%endif
#
%ocaml_create_file_list
#
%if "%build_flavor" == "devel"
# package everything, including the cmxs files
tee -a %name.files < %name.files.devel
%endif

%files -f %name.files
%defattr(-,root,root,-)
%if "%build_flavor" == ""
%doc CHANGES.md README.md
%doc doc/*.rst
%_bindir/*
%_mandir/*/*
%_datadir/emacs
%endif


%changelog
* Thu Apr  4 2024 ohering@suse.de
- Update to version 3.15.0
  see included CHANGES.md file for details
* Mon Mar 11 2024 ohering@suse.de
- Update to version 3.14.2
  see included CHANGES.md file for details
* Mon Feb 12 2024 ohering@suse.de
- Update to version 3.14.0
  see included CHANGES.md file for details
* Mon Feb  5 2024 ohering@suse.de
- Update to version 3.13.1
  see included CHANGES.md file for details
* Tue Jan 16 2024 ohering@suse.de
- Update to version 3.13.0
  see included CHANGES.md file for details
* Fri Jan  5 2024 ohering@suse.de
- Update to version 3.12.2
  see included CHANGES.md file for details
* Tue Dec 12 2023 ohering@suse.de
- Update to version 3.12.1
  see included CHANGES.md file for details
* Tue Oct 10 2023 ohering@suse.de
- Update to version 3.11.1
  see included CHANGES.md file for details
* Fri Sep 22 2023 ohering@suse.de
- Update to version 3.11.0
  see included CHANGES.md for details
* Tue Aug  8 2023 ohering@suse.de
- Update to version 3.10.0
  see included CHANGES.md for details
* Mon Jul 31 2023 ohering@suse.de
- Update to version 3.9.3
  see included CHANGES.md for details
* Fri Jul  7 2023 ohering@suse.de
- Update to version 3.9.1
  see included CHANGES.md for details
* Fri Jun 23 2023 ohering@suse.de
- Update to version 3.8.3
  see included CHANGES.md for details
* Sat Jun 17 2023 ohering@suse.de
- Update to version 3.8.2
  see included CHANGES.md for details
* Fri May  5 2023 ohering@suse.de
- Update to version 3.7.1
  see included CHANGES.md for details
* Fri Mar  3 2023 ohering@suse.de
- Update to version 3.7.0
  see included CHANGES.md for details
* Fri Jan  6 2023 ohering@suse.de
- Update to version 3.6.2
  see included CHANGES.md for details
* Sun Jan  1 2023 ohering@suse.de
- Update to version 3.5.0
  see included CHANGES.md for details
* Tue Aug  2 2022 ohering@suse.de
- Update to version 3.4.1
  see included CHANGES.md for details
* Wed Jun 22 2022 ohering@suse.de
- Update to version 3.3.1
  see included CHANGES.md for details
* Mon Jun 13 2022 ohering@suse.de
- Update to version 3.2.0
  see included CHANGES.md for details
* Tue Apr 19 2022 ohering@suse.de
- Update to version 3.1.1
  see included CHANGES.md for details
* Sat Apr  9 2022 ohering@suse.de
- Adjust bootstrap of dune. Build the dune binary in the main
  package, and all libraries in the devel subpackage. This reduces
  the number of packages, and fixes dune --version output.
- Remove subpackage bootstrap
* Mon Apr  4 2022 ohering@suse.de
- Update to version 3.0.3
  see included CHANGES.md for details
- Remove subpackage configurator
- Add subpackage bootstrap
* Sun Mar 13 2022 ohering@suse.de
- Update to version 2.9.3
  see included CHANGES.md for details
* Sat Sep 11 2021 ohering@suse.de
- Update to version 2.9.1
  see included CHANGES.md for details
* Fri Apr  9 2021 ohering@suse.de
- Update to version 2.8.5
  see included CHANGES.md for details
* Thu Aug 20 2020 ohering@suse.de
- Update to version 2.7.0
  see included CHANGES.md for details
* Sun Apr 12 2020 ohering@suse.de
- update version 2.5.0
  see included CHANGES.md for details
* Sat Feb 29 2020 ohering@suse.de
- update version 2.4.0
  see included CHANGES.md for details
* Mon Nov 25 2019 ohering@suse.de
- Add compiler-libs-devel to BuildRequires and Requires (bsc#1156934)
* Fri Nov  1 2019 ohering@suse.de
- Require current dune macros
* Tue Oct 15 2019 ohering@suse.de
- Include doc/*.rst to have offline documentation available
* Wed Oct  9 2019 ohering@suse.de
- Update to version 1.11.4:
  see included CHANGES.md for details
* Mon Sep 30 2019 ohering@suse.de
- use dune macros from ocaml-rpm-macros
* Mon Sep 23 2019 ohering@suse.de
- Update to version 1.11.3:
  see included CHANGES.md for details
- Require findlib for ocamlfind, which is used to find ocaml
- Create devel package
* Thu May 30 2019 Andy <andy@onthewings.net>
- Update to version 1.10.0:
  * Restricted the set of variables available for expansion in the
    destination filename of install stanza.
  * Call menhir from context root build_dir.
  * Add coq.pp stanza.
  * Add a new more generic form for the promote mode.
  * Allow to promote only a subset of the targets.
  * With lang dune >= 1.10, rules in standard mode are no longer
    allowed to produce targets that are present in the source tree.
  * Allow %%{...} variables in pps flags.
  * Add a 'cookies' option to ppx_rewriter/deriver flags in library
    stanzas.
  * Add more opam metadata and use it to generate .opam files.
  * Add support for hg in dune subst.
  * Add the %%{os_type} variable.
  * Support the .cc extension fro C++ sources.
  * Run ocamlformat relative to the context root.
  * Other bug fixes and improvements. For details, see
    https://github.com/ocaml/dune/blob/1.10.0/CHANGES.md
- Update %%install.
- Install dune-config.5 manpage.
* Thu May 16 2019 Andy <andy@onthewings.net>
- Update to version 1.9.3:
  * Put back library variants in development mode.
  * Fix a bug where dune install would install man pages to
    incorrect paths when compared to opam-installer.
  * Do not fail when a findlib directory doesn't exist.
  * Rename (coqlib ...) to (coq.theory ...).
  * Fix crash when calculating library dependency closure.
  * Fix .install files not being generated.
* Thu Apr 11 2019 Andy <andy@onthewings.net>
- Update to version 1.9.1:
  * Fix invocation of odoc to add previously missing include paths,
    impacting mld files that are not in directories containing
    libraries.
* Wed Apr 10 2019 Andy <andy@onthewings.net>
- Update to version 1.9.0:
  * Add support for library variants and default implementations.
  * Add experimental `dune init` command.
  * Experimental Coq support.
  * Other bug fixes and improvements. For details, see
    https://github.com/ocaml/dune/blob/1.9.0/CHANGES.md
* Wed Mar 13 2019 Andy <andy@onthewings.net>
- Update to version 1.8.2:
  * Correctly write dune-package when version is empty string.
  * Fix auto-generated index.mld. Use correct headings for the
    listing.
* Fri Mar  8 2019 andy@onthewings.net
- Update to version 1.8.0:
  * Various new features and bug fixes. For details, see
    https://github.com/ocaml/dune/blob/1.8.0/CHANGES.md
* Thu Feb 28 2019 andy@onthewings.net
- Update to version 1.7.3:
  * Fix interpretation of META files containing archives with / in
    the filename.
  * Make errors about menhir stanzas be located.
* Sat Feb 23 2019 andy@onthewings.net
- Update to version 1.7.2:
  * Add ${corrected-suffix}, ${library-name} and a few other
    variables to the list of variables to upgrade.
  * Fix "dune subst" failing because the build directory was not
    set.
  * Configurator: Add warning to Pkg_config.query when a full
    package expression is used. Add Pkg_config.query_expr for cases
    when the full power of pkg-config's querying is needed.
  * Fix unavailable, optional implementations eagerly breaking the
    build.
- Update Url to https://dune.build/.
* Mon Feb 18 2019 andy@onthewings.net
- Update to version 1.7.1:
  * Change the layout of build artifacts inside _build.
  * Various other new features and bug fixes. For details, see
    https://github.com/ocaml/dune/blob/1.7.1/CHANGES.md
* Fri Feb  1 2019 andy@onthewings.net
- Update to version 1.6.3:
  * Various new features and bug fixes. For details, see
    https://github.com/ocaml/dune/blob/1.6.3/CHANGES.md
  * Switched to MIT license.
* Thu May 17 2018 antoine.belvire@opensuse.org
- Update to version 1.0+beta20:
  * Add a documentation stanza. This stanza allows one to attach
    .mld files to opam packages. (#570 @rgrinberg)
  * Execute all actions (defined using (action ..)) in the
    context's environment. (#623 @rgrinberg)
  * Add a (universe) special dependency to specify that an action
    depend on everything in the universe. Jbuilder cannot cache the
    result of an action that depend on the universe (#603, fixes
    [#255] @diml)
  * Add a (package <package>) dependency specification to indicate
    dependency on a whole package. Rules depending on whole
    package will be executed in an environment similar to the one
    we get once the package is installed (#624, @rgrinberg and @diml)
  * Display documentation in alphabetical order. This is relevant
    to packages, libraries, and modules. (#647, fixes #606
    @rgrinberg).
  * Missing asm in ocaml -config on bytecode only architecture is
    no longer fatal. The same kind of fix is preemptively applied
    to C compilers being absent. (#646, fixes $637 @rgrinberg)
  * Use the host's PATH variable when running actions during cross
    compilation (#649, fixes #625 @rgrinberg)
  * Fix incorrect include (-I) flags being passed to odoc. These
    flags should be directories that include .odoc files, rather
    than the include flags of the libraries. (#652 fixes #651
    @rgrinberg)
  * Fix a regression introduced by beta19 where the generated
    merlin files didn't include the right -ppx flags in some cases
    (#658 fixes #657 @diml)
  * Fix error message when a public library is defined twice.
    Before jbuilder would raise an uncaught exception (Fixes #661,
    @diml)
  * Fix several cases where external-lib-deps was returning too
    little dependencies (#667, fixes #644 @diml)
  * Place module list on own line in generated entry point mld
    (#670 @antron)
  * Cosmetic improvements to generated entry point mld (#653
    @trefis)
- Changes from previous releases:
  * See https://github.com/ocaml/dune/releases.
* Tue Jan 30 2018 olaf@aepfle.de
- Initial version 1.0.20180129.a3ff5e5
